Package: ROptEst
Version: 1.3.5
Date: 2025-01-12
Title: Optimally Robust Estimation
Description: R infrastructure for optimally robust estimation in general smoothly
            parameterized models using S4 classes and methods as described Kohl, M.,
            Ruckdeschel, P., and Rieder, H. (2010), <doi:10.1007/s10260-010-0133-0>, and in
            Rieder, H., Kohl, M., and Ruckdeschel, P. (2008), <doi:10.1007/s10260-007-0047-7>.
Depends: R(>= 3.4), methods, distr(>= 2.8.0), distrEx(>= 2.8.0),
        distrMod(>= 2.8.1), RandVar(>= 1.2.0), RobAStBase(>= 1.2.0)
Imports: startupmsg(>= 1.0.0), MASS, stats, graphics, utils, grDevices
Suggests: RobLox
Authors@R: c(person("Matthias", "Kohl", role=c("cre", "cph"),
            email="Matthias.Kohl@stamats.de", comment = c(ORCID = "0000-0001-9514-8910")),
            person("Mykhailo", "Pupashenko", role="ctb", comment="contributed wrapper
            functions for diagnostic plots"), person("Gerald", "Kroisandt", role="ctb",
            comment="contributed testing routines"), person("Peter", "Ruckdeschel",
            role=c("aut", "cph"), comment = c(ORCID = "0000-0001-7815-4809")))
ByteCompile: yes
License: LGPL-3
URL: http://robast.r-forge.r-project.org/
Encoding: UTF-8
LastChangedDate: {$LastChangedDate: 2025-01-12 01:50:47 +0100 (So, 12.
        Jan 2025) $}
LastChangedRevision: {$LastChangedRevision: 1324 $}
VCS/SVNRevision: 1323
NeedsCompilation: no
Packaged: 2025-01-12 15:08:33 UTC; kohlm
Author: Matthias Kohl [cre, cph] (<https://orcid.org/0000-0001-9514-8910>),
  Mykhailo Pupashenko [ctb] (contributed wrapper functions for diagnostic
    plots),
  Gerald Kroisandt [ctb] (contributed testing routines),
  Peter Ruckdeschel [aut, cph] (<https://orcid.org/0000-0001-7815-4809>)
Maintainer: Matthias Kohl <Matthias.Kohl@stamats.de>
Repository: CRAN
Date/Publication: 2025-01-15 12:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 10:08:27 UTC; unix
