import("methods")
import("distr")
import("distrEx")
import("RandVar")
import("distrMod")
import("RobAStBase")
importFrom("startupmsg", "buildStartupMessage", "infoShow")
importFrom("grDevices", "dev.list")
importFrom("graphics", "abline", "axis", "box", "par", 
           "points", "text", "matlines", "matpoints", "mtext",
           "title")
importFrom("stats", "complete.cases", "dnorm", "na.omit", "optim",
             "optimize", "pnorm", "qnorm", "uniroot")
importFrom("utils", "read.csv", "read.table", "str", "write.table", 
           "getFromNamespace")
importFrom("graphics", "abline")
importFrom("MASS", "ginv")

exportClasses("asAnscombe", "asL1", "asL4") 
exportMethods("optIC", 
              "getInfRobIC", 
              "getFixRobIC",
              "getAsRisk", 
              "getInfRad", 
              "getInfClip", 
              "getFixClip",
              "getInfGamma", 
              "getInfCent", 
              "getInfStand", 
              "getInfV", 
              "getRiskIC", 
              "optRisk", 
              "radiusMinimaxIC", 
              "getIneffDiff", 
              "leastFavorableRadius",
              "lowerCaseRadius",
              "minmaxBias", "getBiasIC", 
              "getL1normL2deriv",
              "getModifyIC")
exportMethods("updateNorm", "scaleUpdateIC", "eff", 
              "get.asGRisk.fct", "getStartIC", "plot",
			  "comparePlot", "getRiskFctBV", "roptestCall",
			  "checkIC", "makeIC", "kStepTimings")
export("getL2normL2deriv",
       "asAnscombe", "asL1", "asL4", 
	   "getReq", "getMaxIneff", "getRadius")
export("roptest","roptest.old", "robest",
       "OBREstimator", "RMXEstimator", "MBREstimator", "OMSEstimator",
       "getLagrangeMultByOptim","getLagrangeMultByIter")
export("genkStepCtrl", "genstartCtrl", "genstartICCtrl", "gennbCtrl")
export("cniperCont", "cniperPoint", "cniperPointPlot")
export(".generateInterpGrid",".getLMGrid",".saveGridToCSV", ".readGridFromCSV")
export(".RMXE.th",".OMSE.th", ".MBRE.th")
export("CniperPointPlot")
